==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator1/dialogs_de.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Welch glorreiche Zivilisation. So viele Jahrhunderte unter Wasser und ihre Fahrstühle funktionieren immer noch.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Besonders, wenn wir sie schieben.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Aber nur nach unten.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Siehst du diese Muschel?")


dialogId("zd1-v-talis", "font_big", "It`s an age-old talisman for elevator builders who always said 'Build well. Build with Shell`.")
dialogStr("Das ist ein uralter Glücksbringer für Fahrstuhlbauer, die immer gesagt haben \"Baue schnell, bau` mit Shell\".")


dialogId("zd1-m-poved", "font_small", "Isn`t that shell a little bit familiar?")
dialogStr("Kommt dir die Muschel bekannt vor?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Die sollten sich schämen. Das ist unterschwellige Werbung.")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Den Schädel kenn` ich irgendwoher.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Alle menschlichen Schädel sehen gleich aus... Im Gegensatz zu Fischskeletten.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Das ist ein schwerer Weg.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Ich fühle mich wie eine Maus in der Tretmühle .")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Eine Tretmühle für Fische? Aber wir haben doch nur Flossen.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I`m over heeeere...")
dialogStr("Huhu, Huhuuu... Ich bin hier drüüüüben...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I`ll tell you how to solve all the levels...")
dialogStr("Huhu, wenn ihr wollt, werde ich euch sagen, wie ihr alle Ebenen löst...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Huhu, Huhuuu, ich weiß, warum die Stadt versunken ist!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn`t anyone paying attention to me?")
dialogStr("Huhuuu, warum beachtet mich niemand?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Huhuuu! Warum ignoriert ihr mich?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Huhu, haaaaloo, Fische! Hört mir doch mal zu!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elevator1/dialogs_de.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Welch glorreiche Zivilisation. So viele Jahrhunderte unter Wasser und ihre Fahrstühle funktionieren immer noch.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Besonders, wenn wir sie schieben.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Aber nur nach unten.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Siehst du diese Muschel?")


dialogId("zd1-v-talis", "font_big", "It’s an age-old talisman for elevator builders who always said 'Build well. Build with Shell’.")
dialogStr("Das ist ein uralter Glücksbringer für Fahrstuhlbauer, die immer gesagt haben \"Baue schnell, bau’ mit Shell\".")


dialogId("zd1-m-poved", "font_small", "Isn’t that shell a little bit familiar?")
dialogStr("Kommt dir die Muschel bekannt vor?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Die sollten sich schämen. Das ist unterschwellige Werbung.")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Den Schädel kenn’ ich irgendwoher.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Alle menschlichen Schädel sehen gleich aus... Im Gegensatz zu Fischskeletten.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Das ist ein schwerer Weg.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Ich fühle mich wie eine Maus in der Tretmühle .")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Eine Tretmühle für Fische? Aber wir haben doch nur Flossen.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I’m over heeeere...")
dialogStr("Huhu, Huhuuu... Ich bin hier drüüüüben...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I’ll tell you how to solve all the levels...")
dialogStr("Huhu, wenn ihr wollt, werde ich euch sagen, wie ihr alle Ebenen löst...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Huhu, Huhuuu, ich weiß, warum die Stadt versunken ist!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn’t anyone paying attention to me?")
dialogStr("Huhuuu, warum beachtet mich niemand?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Huhuuu! Warum ignoriert ihr mich?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Huhu, haaaaloo, Fische! Hört mir doch mal zu!")
